<?php

function prosepoint_config_workflow() {
  // Configuration data
  $workflow_name = t('Workflow');
  $workflow_options = array('comment_log_node' => 1, 'comment_log_tab' => 1);
  $workflow_tabs = array('author', 5, 4, 3);
  $workflow_states = array(
    'draft' => array('state' => t('Draft'), 'weight' => 1),
    'review' => array('state' => t('Ready for review'), 'weight' => 2),
    'public' => array('state' => t('Public'), 'weight' => 3),
    'private' => array('state' => t('Private'), 'weight' => 4),
    'archived' => array('state' => t('Archived'), 'weight' => 5),
  );
  // Luckily, we have the same roles (author, admin, editor) permitted for all transitions
  $roles_allowed = array('author' => 1, '5' => 1, '4' => 1);

  // Various workflow access 'masks'
  // Role numbers: author = -1, anon = 1, auth = 2, staff = 3, editor = 4, admin = 5
  $access_admin_editor_author = array(-1 => -1, 1 => 0, 2 => 0, 3 => 0, 4 => 4, 5 => 5);
  $access_admin_editor_staff_author = array(-1 => -1, 1 => 0, 2 => 0, 3 => 3, 4 => 4, 5 => 5);
  $access_anon_auth = array(-1 => 0, 1 => 1, 2 => 2, 3 => 0, 4 => 0, 5 => 0);
  $access_auth = array(-1 => 0, 1 => 0, 2 => 2, 3 => 0, 4 => 0, 5 => 0);
  $workflow_access = array(
    'draft' => array('view' => $access_admin_editor_author,
                     'update' => $access_admin_editor_author,
                     'delete' => $access_admin_editor_author,
    ),
    'review' => array('view' => $access_admin_editor_staff_author,
                     'update' => $access_admin_editor_author,
                     'delete' => $access_admin_editor_author,
    ),
    'public' => array('view' => $access_anon_auth,
                     'update' => $access_admin_editor_author,
                     'delete' => $access_admin_editor_author,
    ),
    'private' => array('view' => $access_auth,
                     'update' => $access_admin_editor_author,
                     'delete' => $access_admin_editor_author,
    ),
    'archived' => array('view' => $access_auth,
                     'update' => $access_admin_editor_author,
                     'delete' => $access_admin_editor_author,
    ),
  );

  // Create workflow and save configuration
  $wid = workflow_create($workflow_name);
  workflow_update($wid, $workflow_name, $workflow_tabs, $workflow_options);

  // Fetch (creation) state and remember for later. There should only one state at this point. 
  $result = db_query('SELECT sid, wid, state, weight, sysid, status FROM {workflow_states} WHERE wid = %d', $wid);  
  $data = db_fetch_object($result);
  $creation_state = array(
    'sid' => $data->sid,
    'state' => $data->state,
    'weight' => $data->weight,
    'sysid' => $data->sysid,
    'status' => $data->status,
  );

  // Save states
  foreach ($workflow_states as $key => $unused) {
    $workflow_states[$key]['wid'] = $wid;    
    $sid = workflow_state_save($workflow_states[$key]);
    $workflow_states[$key]['sid'] = $sid;
  }

  // Now poke (creation) state into our array
  $workflow_states['creation'] = $creation_state;

  // Save transitions
  $transitions = array();
  foreach ($workflow_states as $from_state) {
    foreach ($workflow_states as $to_state) {
      $transitions[$from_state['sid']][$to_state['sid']] = $roles_allowed;
    }
  }
  workflow_update_transitions($transitions);

  // Save workflow access
  // Construct a dummy form_state['values']['workflow_access'] array
  $form_state = array();
  foreach ($workflow_access as $name => $access) {
    $sid = $workflow_states[$name]['sid'];
    $form_state['values']['workflow_access'][$sid] = $access;
  }
  workflow_access_form_submit(null, $form_state);

  // Save workflow mapping
  $form_values = array();
  $node_types = node_get_types();
  foreach ($node_types as $type => $name) {
    $form_values[$type]['workflow'] = 0;
    $form_values[$type]['placement'] = array('node' => 'node', 'comment' => 0);    
  }
  // Poke a workflow for story type
  $form_values['story']['workflow'] = $wid;
  workflow_types_save($form_values);

  // Save for future reference
  variable_set('pp_publishing_wid', $wid);
  // Only save the state's sid
  foreach ($workflow_states as $name => $state) {
    $workflow_states[$name] = array('sid' => $state['sid']);
  }
  variable_set('pp_publishing_states', $workflow_states);
}

