<?php
/*
 * Copyright 2008 ThinkLeft (thinkleft.com.au)
 * Copyright 2008 ProsePoint (www.prosepoint.org)
 */


/************************************************************
*                    GALLERY SETTINGS                       *
************************************************************/

function pp_ig_global_settings_form() {
  $form = array();
  $form['gallery_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Global settings'),
  );
  
  $form['gallery_settings']['pp_ig_gallery_thumbnail_preset'] = array(
    '#title' => t('Size of gallery cover images'),
    '#type' => 'select',
    '#options' => pp_image_presets_select(),
    '#default_value' => variable_get('pp_ig_gallery_thumbnail_preset', 'thumbnail'),
    '#required' => TRUE,
  );

  return system_settings_form($form);
}

function pp_ig_gallery_overview() {
  $vocabulary = variable_get('pp_ig_gallery_vocabulary', '--');
  if ($vocabulary == '--') {
    $output = t('You have not selected a vocabulary for your image gallery hierarchy.');
  }
  else {
    module_load_include('inc', 'taxonomy', 'taxonomy.admin');
    $output = drupal_get_form('taxonomy_overview_terms', taxonomy_vocabulary_load($vocabulary));
    drupal_set_title(t('Image galleries'));
  }
  
  return $output;
}

function pp_ig_add_gallery() {
  $vocabulary = variable_get('pp_ig_gallery_vocabulary', '--');
  if ($vocabulary == '--') {
    $output = t('You have not selected a vocabulary for your image gallery hierarchy.');
  }
  else {
    module_load_include('inc', 'taxonomy', 'taxonomy.admin');
    $output = drupal_get_form('taxonomy_form_term' , taxonomy_vocabulary_load($vocabulary));
  }
  return $output;
}

function pp_ig_gallery_settings(&$form, $form_state, $form_id) {
  // Don't do anything if this is a delete confirmation
  if (isset($form_state['confirm_delete'])) {
    return;
  }

  if (isset($form['#term']['tid'])) {
    $term = taxonomy_get_term($form['#term']['tid']);
    $gallery = pp_ig_gallery_load($term);
  }

  if ($gallery) {    
    $form['gallery_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Gallery settings'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#description' => t(''),
      '#tree' => FALSE,
    );

    $result = taxonomy_select_nodes(array($term->tid), 'or', 0, FALSE, 'n.sticky DESC, n.title ASC');
    $options = array(0 => '- None selected -');
    while ($object = db_fetch_object($result)) {
      $options[$object->nid] = $object->title;
    }

    $form['gallery_settings']['cover_image'] = array(
      '#type' => 'select',
      '#title' => t('Cover image'),
      '#options' => $options,
      '#default_value' => isset($options[$gallery->cover_image]) ? $gallery->cover_image : 0,
    );

    $form['advanced']['#weight'] = 1;
    $form['submit']['#weight'] = 2;
    $form['delete']['#weight'] = 3;
  }
}

/************************************************************
*                      GALLERY PAGES                        *
************************************************************/

function pp_ig_gallery_page($term = null) {
  // Add default gallery styling
  drupal_add_css(drupal_get_path('module', 'pp_ig') . '/pp_image_gallery.css', 'module', 'all', FALSE);

  $gallery = isset($term->tid) ? pp_ig_gallery_load($term) : array();

  // Fetch the galleries in the level just below this one
  $vid = isset($term->vid) ? $term->vid : variable_get('pp_ig_gallery_vocabulary', '');
  $subgalleries = taxonomy_get_tree($vid, isset($term->tid) ? $term->tid : 0, -1, 1);
  foreach ($subgalleries as $k => $subgallery) {
    $subgallery = pp_ig_gallery_load($subgallery);

    // Render cover image if there is one. 
    if ($subgallery->cover_image > 0) {
      $cover_image = node_load($subgallery->cover_image);
      $info = pp_image_imagefield_info($cover_image->field_image, variable_get('pp_ig_gallery_thumbnail_preset', 'thumbnail'));
      if ($info) {
        $subgallery->thumbnail = theme('image', $info['filepath'], $subgallery->name, $cover_image->title);
      }
    }
    
    $subgalleries[$k] = $subgallery;
  }

  // Render
  $output = theme('pp_image_gallery', $gallery, $subgalleries);

  // Adjust breadcrumb (after the view has executed)
  if (isset($term->tid)) {
    $parents = taxonomy_get_parents($term->tid);
    $breadcrumb = array();
    $breadcrumb[] = l(t('Home'), NULL);
    $breadcrumb[] = l(t('Image gallery'), 'image_gallery');
    foreach ($parents as $parent) {
      // Add parents to breadcrumb navigation
      $breadcrumb[] = l($parent->name, 'image_gallery/'. $parent->tid);
    }
    drupal_set_breadcrumb($breadcrumb);
  }

  return $output;
}

function theme_pp_image_gallery($gallery = array(), $subgalleries = array()) {
  $items = array();
  $count = 0;
  foreach ($subgalleries as $subgallery) {
    $path = taxonomy_term_path($subgallery);
    $text = '<div class="gallery-title">' . l($subgallery->name, $path) . '</div>';
    if ($subgallery->thumbnail) {
      $text = '<div class="gallery-thumbnail">' . l($subgallery->thumbnail, $path, array('html' => TRUE)) . '</div>' . $text;
    }
    $count++;
    $items[] = '<div class="gallery gallery-' . $count. '">' . $text . '</div>';
  }

  if ($items) {
    $output = '<div class="galleries clear-block"><h3 class="galleries-title">' . t('Galleries') . '</h3>' . theme('item_list', $items) . '</div>';
  }

  if ($gallery->description) {
    $output .= '<div class="description">' . check_plain($gallery->description) . '</div>';
  }

  // Use a view to display the images
  // Note, the view calls drupal_set_title() 
  if ($view = views_get_view('images_list')) {
    $args = isset($gallery->tid) ? array($gallery->tid) : array();
    $output .= $view->execute_display('page_2', $args);
    $view->destroy();
  }
  else {
    drupal_set_message(t('ProsePoint error: Missing view %view', array('%view' => 'images_list')), 'error');
  }

  $output = '<div class="pp_image_gallery">' . $output . '</div>';

  return $output;
}

